---
title: <span class="badge object-type-disjunction"></span> BucketAggregation
---
# <span class="badge object-type-disjunction"></span> BucketAggregation

## Definition

```python
BucketAggregation: typing.TypeAlias = typing.Union[elasticsearch.DateHistogram, elasticsearch.Histogram, elasticsearch.Terms, elasticsearch.Filters, elasticsearch.GeoHashGrid, elasticsearch.Nested]
```
